import { Observable } from '../../common/utils';
import { Logger } from '../../common/utils/logger';
import { BaseComponent } from '../../components/base';
import { DefaultLauncher, LauncherFacade, LauncherOptions } from './types';
export declare class Launcher extends Observable implements DefaultLauncher {
    protected readonly logger: Logger;
    private isDestroyed;
    private activeComponents;
    private componentsToAttachAfterJoin;
    private activeComponentsInstances;
    private participant;
    private ioc;
    private room;
    private eventBus;
    private slotService;
    private useStore;
    constructor({ participant, group: participantGroup }: LauncherOptions);
    /**
     * @function addComponent
     * @description add component to launcher
     * @param component - component to add
     * @returns {void}
     */
    addComponent: (component: Partial<BaseComponent>) => Promise<void>;
    /**
     * @function attachComponentsAfterJoin
     * @description attach components after join
     * @returns {void}
     */
    private attachComponentsAfterJoin;
    /**
     * @function removeComponent
     * @description remove component from launcher
     * @param component - component to remove
     * @returns {void}
     */
    removeComponent: (component: Partial<BaseComponent>) => void;
    /**
     * @function destroy
     * @description destroy launcher and all components
     * @returns {void}
     */
    destroy: () => void;
    /**
     * @function canAddComponent
     * @description verifies if component can be added
     * @param component - component to be added
     * @returns {boolean}
     */
    private canAddComponent;
    /**
     * @function onAuthentication
     * @description on authentication
     * @param isAuthenticated - return if the user is authenticated
     * @returns {void}
     */
    private onAuthentication;
    /**
     * @function onLocalParticipantUpdateOnStore
     * @description handles the update of the local participant in the store.
     * @param {Participant} participant - new participant data
     * @returns {void}
     */
    private onLocalParticipantUpdateOnStore;
    private onLocalParticipantUpdateOnCore;
    private onParticipantsListUpdateOnCore;
    private onSameAccount;
    /** IO */
    /**
     * @function startIOC
     * @description start IO service
     * @returns {void}
     */
    private startIOC;
    /**
     * @function onConnectionStateChange
     * @description on connection state change
     * @param state - connection state
     * @returns {void}
     */
    private onConnectionStateChange;
    /**
     * @function onParticipantJoinedIOC
     * @description on participant joined
     * @param presence - participant presence
     * @returns {void}
     */
    private onParticipantJoinedIOC;
    /**
     * @function onParticipantLeaveIOC
     * @description on participant leave
     * @param presence - participant presence
     * @returns {void}
     */
    private onParticipantLeaveIOC;
    /**
     * @function onParticipantUpdatedIOC
     * @description on participant updated
     * @param presence - participant presence
     * @returns {void}
     */
    private onParticipantUpdatedIOC;
}
/**
 * @function Launcher
 * @description create launcher instance
 * @param options - launcher options
 * @returns {LauncherFacade}
 */
declare const _default: (options: LauncherOptions) => LauncherFacade;
export default _default;
